/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.add;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.overlay.Overlay;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarArray;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;

/**
 * Block to add one or several {@link Overlay} to a Sequence
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Add Overlays")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class AddOverlays extends Plugin implements SequenceBlock {
    final protected VarSequence inputSequence = new VarSequence("Sequence", null);
    final protected VarArray<Overlay> overlays = new VarArray<>("Overlay(s)", Overlay[].class, new Overlay[0]) {
        @Override
        public @NotNull String getValueAsString() {
            final Overlay[] value = getValue();

            if (value == null || value.length == 0)
                return "No overlay";

            return value.length + " overlay";
        }
    };

    @Override
    public void run() {
        final Sequence s = inputSequence.getValue();
        if (s == null)
            throw new VarException(inputSequence, "Input sequence is null.");

        final Overlay[] o = overlays.getValue();
        if (o != null) {
            s.beginUpdate();
            try {
                for (final Overlay overlay : o)
                    s.addOverlay(overlay);
            }
            finally {
                s.endUpdate();
            }
        }

    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("sequence", inputSequence);
        inputMap.add("overlay(s)", overlays);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        //
    }
}
