/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.creation;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.bioimageanalysis.icy.model.sequence.SequenceUtil;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;

/**
 * @author Thomas Provoost
 */
@IcyPluginName("Duplicate Sequence")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class DuplicateSequence extends Plugin implements SequenceBlock {
    final protected VarSequence in = new VarSequence("sequence", null);
    final protected VarSequence out = new VarSequence("duplicated", null);

    @Override
    public void run() {
        final Sequence s = in.getValue();
        if (s == null)
            throw new VarException(in, "Input Sequence is null.");

        try {
            out.setValue(SequenceUtil.getCopy(s));
        }
        catch (final InterruptedException e) {
            // nothing to do
        }
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("sequence", in);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("duplicated", out);
    }
}
