/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.extract;

import org.bioimageanalysis.icy.common.collection.CollectionUtil;
import org.bioimageanalysis.icy.common.geom.shape.ShapeUtil;
import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.roi.ROI;
import org.bioimageanalysis.icy.model.roi.ROIUtil;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.bioimageanalysis.icy.model.sequence.SequenceUtil;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarMutable;
import plugins.adufour.vars.lang.VarSequence;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Thomas Provoost
 */
@IcyPluginName("Crop Sequence")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class CropSequence extends Plugin implements SequenceBlock {
    final protected VarSequence inputSequence = new VarSequence("Sequence", null);
    VarMutable inputROIs = new VarMutable("ROI(s)", null) {
        @Override
        public boolean isAssignableFrom(final @NotNull Var source) {
            return (ROI.class == source.getType()) || (ROI[].class == source.getType());
        }
    };
    final protected VarSequence outputSequence = new VarSequence("Cropped", null);

    @Override
    public void run() {
        outputSequence.setValue(null);

        final Sequence s = inputSequence.getValue();
        if (s == null)
            return;

        final Object obj = inputROIs.getValue();
        if (obj == null)
            return;

        final List<ROI> rois;

        if (obj instanceof ROI) {
            rois = new ArrayList<>();
            rois.add((ROI) obj);
        }
        else
            rois = CollectionUtil.asList((ROI[]) obj);

        try {
            final ROI roi = ROIUtil.merge(rois, ShapeUtil.BooleanOperator.OR);

            outputSequence.setValue(SequenceUtil.getSubSequence(s, roi));
        }
        catch (final InterruptedException e) {
            // nothing to do
        }
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("sequence", inputSequence);
        inputMap.add("roi", inputROIs);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("cropped", outputSequence);
    }
}
