/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.images;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.image.IcyBufferedImage;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;

/**
 * Add an image to the Sequence.
 *
 * @author Thomas Provoost
 */
@IcyPluginName("Add Image")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class AddImage extends Plugin implements SequenceBlock {
    final protected Var<IcyBufferedImage> in = new Var<>("Image", IcyBufferedImage.class);
    final protected VarSequence varSeq = new VarSequence("Sequence", null);

    @Override
    public void run() {
        final Sequence s = varSeq.getValue();
        if (s == null)
            throw new VarException(varSeq, "Input sequence is null.");
        s.addImage(in.getValue());
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("sequence", varSeq);
        inputMap.add("image", in);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        //
    }
}
