/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.importer;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.io.IOBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.Var;
import plugins.adufour.vars.util.VarException;

/**
 * Block to close currently opened SequenceFileImporter.
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Close SequenceFileImporter")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class SequenceFileImporterClose extends Plugin implements IOBlock {
    final protected Var<PositionedSequenceFileImporter> importer;

    public SequenceFileImporterClose() {
        super();

        importer = new Var<>("Importer", PositionedSequenceFileImporter.class);
    }

    @Override
    public void run() {
        final PositionedSequenceFileImporter pi = importer.getValue();

        if (pi == null)
            throw new VarException(importer, "Importer is null !");

        try {
            pi.importer.close();
        }
        catch (final Exception e) {
            throw new VarException(importer, e.getMessage());
        }
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("importer", importer);
    }

    @Override
    public void declareOutput(final VarList outputMap) {
        //
    }
}
