/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.infos;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarInteger;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;

/**
 * @author Thomas Provoost
 */
@IcyPluginName("Get Sequence Dimensions")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class Dimensions extends Plugin implements SequenceBlock {
    VarSequence varSeq = new VarSequence("Sequence", null);
    VarInteger sizeZ = new VarInteger("Size Z", 1);
    VarInteger sizeT = new VarInteger("Size T", 1);
    VarInteger sizeC = new VarInteger("Size C", 1);
    VarInteger width = new VarInteger("Width", 1);
    VarInteger height = new VarInteger("Height", 1);

    @Override
    public void run() {
        final Sequence s = varSeq.getValue();
        if (s == null)
            throw new VarException(varSeq, "Input sequence is null.");

        width.setValue(s.getWidth());
        height.setValue(s.getHeight());
        sizeC.setValue(s.getSizeC());
        sizeZ.setValue(s.getSizeZ());
        sizeT.setValue(s.getSizeT());
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("sequence", varSeq);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("width", width);
        outputMap.add("height", height);
        outputMap.add("size C", sizeC);
        outputMap.add("size Z", sizeZ);
        outputMap.add("size T", sizeT);
    }
}
