/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.infos;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarInteger;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.lang.VarString;
import plugins.adufour.vars.util.VarException;

/**
 * @author Thomas Provoost
 */
@IcyPluginName("Get Channel Name")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class GetChannelName extends Plugin implements SequenceBlock {
    private final VarSequence varSequence = new VarSequence("Sequence", null);
    private final VarInteger varIdx = new VarInteger("Channel", 0);
    private final VarString varName = new VarString("Name", "");

    @Override
    public void run() {
        final Sequence s = varSequence.getValue();
        if (s == null)
            throw new VarException(varSequence, "Sequence is null");

        final int index = varIdx.getValue();
        if (index < 0 || index >= s.getSizeC())
            throw new VarException(varIdx, "Wrong channel index.");

        varName.setValue(s.getChannelName(index));
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("sequence", varSequence);
        inputMap.add("index", varIdx);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("name", varName);
    }
}
