/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.infos;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarArray;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.util.VarException;

import java.util.ArrayList;
import java.util.List;

/**
 * Block to retrieve all channels name from a given sequence
 *
 * @author Stephane Dallongeville
 * @see GetChannelName
 * @see SetChannelsName
 */
@IcyPluginName("Get Channels Name")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class GetChannelsName extends Plugin implements SequenceBlock {
    private final VarSequence varSequence = new VarSequence("Sequence", null);
    private final VarArray<String> varNames = new VarArray<>("Names", String[].class, new String[0]);

    @Override
    public void run() {
        final Sequence s = varSequence.getValue();
        if (s == null)
            throw new VarException(varSequence, "Sequence is null");

        final List<String> names = new ArrayList<>();

        for (int c = 0; c < s.getSizeC(); c++)
            names.add(s.getChannelName(c));

        varNames.setValue(names.toArray(new String[0]));
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("sequence", varSequence);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("names", varNames);
    }
}
