/*
 * Copyright (c) 2010-2024. Institut Pasteur.
 *
 * This file is part of Icy.
 * Icy is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Icy is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Icy. If not, see <https://www.gnu.org/licenses/>.
 */

package plugins.tprovoost.sequenceblocks.infos;

import org.bioimageanalysis.icy.extension.plugin.abstract_.Plugin;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginIcon;
import org.bioimageanalysis.icy.extension.plugin.annotation_.IcyPluginName;
import org.bioimageanalysis.icy.io.FileUtil;
import org.bioimageanalysis.icy.model.sequence.Sequence;
import org.jetbrains.annotations.NotNull;
import plugins.adufour.blocks.tools.sequence.SequenceBlock;
import plugins.adufour.blocks.util.VarList;
import plugins.adufour.vars.lang.VarBoolean;
import plugins.adufour.vars.lang.VarSequence;
import plugins.adufour.vars.lang.VarString;
import plugins.adufour.vars.util.VarException;

/**
 * Returns the origin filename (from where the sequence has been loaded / saved)
 *
 * @author Stephane Dallongeville
 */
@IcyPluginName("Get File Name")
@IcyPluginIcon(path = "/SequenceBlocks_icon.png")
public class GetFileName extends Plugin implements SequenceBlock {
    final protected VarSequence varSequence = new VarSequence("Sequence", null);
    final protected VarString filename = new VarString("Filename", "");
    final protected VarBoolean withFolder = new VarBoolean("Folder", Boolean.TRUE);
    final protected VarBoolean withExtension = new VarBoolean("Extension", Boolean.TRUE);

    @Override
    public void run() {
        final Sequence s = varSequence.getValue();

        if (s == null)
            throw new VarException(varSequence, "Sequence is null");

        String result = s.getFilename();

        // remove folder information ?
        if (!withFolder.getValue())
            result = FileUtil.getFileName(result);
        // remove extension ?
        if (!withExtension.getValue())
            result = FileUtil.setExtension(result, "");

        filename.setValue(result);
    }

    @Override
    public void declareInput(final @NotNull VarList inputMap) {
        inputMap.add("sequence", varSequence);
        inputMap.add("folder", withFolder);
        inputMap.add("extension", withExtension);
    }

    @Override
    public void declareOutput(final @NotNull VarList outputMap) {
        outputMap.add("name", filename);
    }
}